#ifndef ACTIONWITHTARGETDIALOG_H
#define ACTIONWITHTARGETDIALOG_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "actiondialog.h"
#include "subtitleline.h"

#include <qwidget.h>

#include <klocale.h>

class QGridLayout;
class QButtonGroup;

namespace SubtitleComposer
{
	class ActionWithTargetDialog : public ActionDialog
	{
		Q_OBJECT

		public:

			typedef enum { AllLines=0, Selection, FromSelected, UpToSelected, None } LinesTarget;

			/// LINES TARGET
			LinesTarget selectedLinesTarget() const;
			void setSelectedLinesTarget( LinesTarget target );

			bool isLinesTargetEnabled( LinesTarget target ) const;
			void setLinesTargetEnabled( LinesTarget target, bool enabled );

			bool selectionTargetOnlyMode() const;
			void setSelectionTargetOnlyMode( bool value );

			/// TEXTS TARGET

			SubtitleLine::OpMode nonTranslationModeTarget() const;
			void setNonTranslationModeTarget( SubtitleLine::OpMode target );

			SubtitleLine::OpMode selectedTextsTarget() const;
			void setSelectedTextsTarget( SubtitleLine::OpMode target );

			bool isTextsTargetEnabled( SubtitleLine::OpMode target ) const;
			void setTextsTargetEnabled( SubtitleLine::OpMode target, bool enabled );

			bool translationMode() const;
			void setTranslationMode( bool value );

		public slots:

			virtual int exec();

		protected:

			ActionWithTargetDialog( const QString& title, QWidget* parent=0 );
			virtual ~ActionWithTargetDialog();

			QButtonGroup* createTargetButtonGroup( const QString& title=i18n( "Apply to" ), bool addToLayout=true );

			void setTargetButtonsHidden( QButtonGroup* targetButtonGroup, int buttonGroupColumn, bool hidden );
			void updateTargetGroupHidden();

			void createLinesTargetButtons();
			void createTextsTargetButtons();

			void _setSelectionTargetOnlyMode( bool value, bool force );
			void _setTranslationMode( bool enabled, bool force );

		protected:

			QButtonGroup* m_targetButtonGroup;
			QGridLayout* m_targetLayout;

			QButtonGroup* m_linesTargetButtonGroup;
			QButtonGroup* m_textsTargetButtonGroup;

		private:

			bool m_selectionTargetOnlyMode;
			bool m_selectionTargetWasChecked;

			bool m_translationMode;
			SubtitleLine::OpMode m_nonTranslationModeTarget;
	};


	class ActionWithLinesTargetDialog : public ActionWithTargetDialog
	{
		Q_OBJECT

		public:

			ActionWithLinesTargetDialog( const QString& title, QWidget* parent=0 );
			ActionWithLinesTargetDialog( const QString& title, const QString& desc, QWidget* parent=0 );

		public slots:

			virtual int exec();
	};

	class ActionWithTextsTargetDialog : public ActionWithTargetDialog
	{
		Q_OBJECT

		public:

			ActionWithTextsTargetDialog( const QString& title, QWidget* parent=0 );
			ActionWithTextsTargetDialog( const QString& title, const QString& desc, QWidget* parent=0 );

		public slots:

			virtual int exec();
	};

	class ActionWithLinesAndTextsTargetDialog : public ActionWithTargetDialog
	{
		Q_OBJECT

		public:

			ActionWithLinesAndTextsTargetDialog( const QString& title, QWidget* parent=0 );
			ActionWithLinesAndTextsTargetDialog( const QString& title, const QString& desc, QWidget* parent=0 );

		public slots:

			virtual int exec();
	};

}

#endif
