/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "autodurationsdialog.h"

#include <qlabel.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qradiobutton.h>

#include <klocale.h>
#include <knuminput.h>


using namespace SubtitleComposer;

AutoDurationsDialog::AutoDurationsDialog( unsigned charMillis, unsigned wordMillis, unsigned lineMillis, QWidget* parent ):
	ActionWithTargetDialog( i18n( "Automatic Durations" ), parent ),
	m_translationMode( false )
{
	QButtonGroup* settingsButtonGroup = createButtonGroup( i18n( "Settings" ) );

	QLabel* charMillisLabel = new QLabel( i18n( "Milliseconds per character" ), settingsButtonGroup );
	charMillisLabel->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );

	m_charMillisSpinBox = new KIntSpinBox( settingsButtonGroup );
	m_charMillisSpinBox->setMinValue( 0 );
	m_charMillisSpinBox->setMaxValue( 1000 );
	m_charMillisSpinBox->setValue( charMillis );

	QLabel* wordMillisLabel = new QLabel( i18n( "Milliseconds per word" ), settingsButtonGroup );
	wordMillisLabel->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );

	m_wordMillisSpinBox = new KIntSpinBox( settingsButtonGroup );
	m_wordMillisSpinBox->setMinValue( 0 );
	m_wordMillisSpinBox->setMaxValue( 1000 );
	m_wordMillisSpinBox->setValue( wordMillis );

	QLabel* lineMillisLabel = new QLabel( i18n( "Milliseconds per line" ), settingsButtonGroup );
	lineMillisLabel->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );

	m_lineMillisSpinBox = new KIntSpinBox( settingsButtonGroup );
	m_lineMillisSpinBox->setMinValue( 0 );
	m_lineMillisSpinBox->setMaxValue( 1000 );
	m_lineMillisSpinBox->setValue( lineMillis );

	m_preventOverlapCheckBox = new QCheckBox( settingsButtonGroup );
	m_preventOverlapCheckBox->setText( i18n( "Prevent overlapping" ) );
	m_preventOverlapCheckBox->setChecked( true );


	m_calculationButtonGroup = createButtonGroup( i18n( "Duration calculation" ) );

	for ( int index = 0; index < SubtitleLine::OpModeUNKNOWN; ++index )
		new QRadioButton( m_calculationButtonGroup );
	m_calculationButtonGroup->find( SubtitleLine::Primary )->setText( i18n( "Use primary text" ) );
	m_calculationButtonGroup->find( SubtitleLine::Secondary )->setText( i18n( "Use translation text" ) );
	m_calculationButtonGroup->find( SubtitleLine::Both )->setText( i18n( "Calculate both and use maximum" ) );

	
	createLinesTargetButtons();


	QGridLayout* settingsLayout = createLayout( settingsButtonGroup );
	settingsLayout->addWidget( charMillisLabel, 0, 0 );
	settingsLayout->addWidget( m_charMillisSpinBox, 0, 1 );
	settingsLayout->addWidget( wordMillisLabel, 1, 0 );
	settingsLayout->addWidget( m_wordMillisSpinBox, 1, 1 );
	settingsLayout->addWidget( lineMillisLabel, 2, 0 );
	settingsLayout->addWidget( m_lineMillisSpinBox, 2, 1 );
	settingsLayout->addMultiCellWidget( m_preventOverlapCheckBox, 3, 3, 0, 1 );

	QGridLayout* calculationLayout = createLayout( m_calculationButtonGroup );
	for ( int index = 0; index < SubtitleLine::OpModeUNKNOWN; ++index )
		calculationLayout->addWidget( m_calculationButtonGroup->find( index ), index, 0 );
}

unsigned AutoDurationsDialog::charMillis() const
{
	return m_charMillisSpinBox->value();
}

unsigned AutoDurationsDialog::wordMillis() const
{
	return m_wordMillisSpinBox->value();
}

unsigned AutoDurationsDialog::lineMillis() const
{
	return m_lineMillisSpinBox->value();
}

bool AutoDurationsDialog::preventOverlap() const
{
	return m_preventOverlapCheckBox->isChecked();
}

bool AutoDurationsDialog::translationMode() const
{
	return m_translationMode;
}

void AutoDurationsDialog::setTranslationMode( bool enabled )
{
	if ( m_translationMode != enabled )
	{
		m_translationMode = enabled;

		if ( m_translationMode )
		{
			m_calculationButtonGroup->find( SubtitleLine::Both )->setEnabled( true );
			static_cast<QRadioButton*>( m_calculationButtonGroup->find( SubtitleLine::Both ) )->setChecked( true );

			m_calculationButtonGroup->show();
		}
		else
		{
			m_calculationButtonGroup->find( SubtitleLine::Primary )->setEnabled( true );
			static_cast<QRadioButton*>( m_calculationButtonGroup->find( SubtitleLine::Primary ) )->setChecked( true );

			m_calculationButtonGroup->hide();
		}
	}
}

SubtitleLine::OpMode AutoDurationsDialog::calculationMode() const
{
	int selectedId = m_calculationButtonGroup->selectedId();
	return selectedId == -1 ? SubtitleLine::OpModeUNKNOWN : (SubtitleLine::OpMode)selectedId;
}
