/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "changeframeratedialog.h"

#include <qlabel.h>
#include <qbuttongroup.h>
#include <qlayout.h>

#include <klocale.h>
#include <kmessagebox.h>
#include <kcombobox.h>


using namespace SubtitleComposer;

ChangeFrameRateDialog::ChangeFrameRateDialog( double fromFramesPerSecond, QWidget* parent ):
	ActionDialog( i18n( "Change Frame Rate" ), parent )
{
	QButtonGroup* settingsButtonGroup = createButtonGroup( i18n( "Settings" ));

	QLabel* fromFramesPerSecondLabel = new QLabel( settingsButtonGroup );
	fromFramesPerSecondLabel->setText( i18n( "Current frame rate" ) );

	m_fromFramesPerSecondComboBox = new KComboBox( false, settingsButtonGroup );
	m_fromFramesPerSecondComboBox->setEditable( true );
	m_fromFramesPerSecondComboBox->insertStringList( QStringList::split( ' ', "15 20 23.976 24 25 29.970 30" ) );
	m_fromFramesPerSecondComboBox->setCurrentItem( 2 );
	setFromFramesPerSecond( fromFramesPerSecond );

	QLabel* toFramesPerSecondLabel = new QLabel( settingsButtonGroup );
	toFramesPerSecondLabel->setText( i18n( "New frame rate" ) );

	m_toFramesPerSecondComboBox = new KComboBox( false, settingsButtonGroup );
	m_toFramesPerSecondComboBox->setEditable( true );
	m_toFramesPerSecondComboBox->insertStringList( QStringList::split( ' ', "15 20 23.976 24 25 29.970 30" ) );
	m_toFramesPerSecondComboBox->setCurrentItem( 2 );

	QGridLayout* settingsLayout = createLayout( settingsButtonGroup );
	settingsLayout->addWidget( fromFramesPerSecondLabel, 0, 0 );
	settingsLayout->addWidget( m_fromFramesPerSecondComboBox, 0, 1 );
	settingsLayout->addWidget( toFramesPerSecondLabel, 1, 0 );
	settingsLayout->addWidget( m_toFramesPerSecondComboBox, 1, 1 );
}

double ChangeFrameRateDialog::fromFramesPerSecond() const
{
	return m_fromFramesPerSecondComboBox->lineEdit()->text().toDouble();
}

void ChangeFrameRateDialog::setFromFramesPerSecond( double framesPerSecond )
{
	m_fromFramesPerSecondComboBox->lineEdit()->setText( QString::number( framesPerSecond, 'f', 3 ) );
}

double ChangeFrameRateDialog::toFramesPerSecond() const
{
	return m_toFramesPerSecondComboBox->lineEdit()->text().toDouble();
}

void ChangeFrameRateDialog::setNewFramesPerSecond( double framesPerSecond )
{
	m_toFramesPerSecondComboBox->lineEdit()->setText( QString::number( framesPerSecond, 'f', 3 ) );
}

void ChangeFrameRateDialog::accept()
{
	bool ok;
	m_fromFramesPerSecondComboBox->lineEdit()->text().toDouble( &ok );
	if ( ! ok )
	{
		KMessageBox::error( this, i18n( "Invalid current frame rate value specified:\n%1" ).arg( m_fromFramesPerSecondComboBox->lineEdit()->text() ) );
		return;
	}

	m_toFramesPerSecondComboBox->lineEdit()->text().toDouble( &ok );
	if ( ! ok )
	{
		KMessageBox::error( this, i18n( "Invalid new frame rate value specified:\n%1" ).arg( m_toFramesPerSecondComboBox->lineEdit()->text() ) );
		return;
	}

	ActionDialog::accept();
}
