/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "clearerrorsdialog.h"

#include <qlayout.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qpushbutton.h>

#include <klocale.h>

using namespace SubtitleComposer;

ClearErrorsDialog::ClearErrorsDialog( QWidget* parent ):
	ActionWithTargetDialog( i18n( "Clear Errors" ), parent )
{
	QButtonGroup* errorsButtonGroup = createButtonGroup( i18n( "Errors to clear" ) );

	int checksCount = 0;
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
	{
		if ( (0x1 << id) & SubtitleLine::SecondaryTextErrors )
			m_errorsCheckBox[id] = 0;
		else
		{
			m_errorsCheckBox[id] = new QCheckBox( errorsButtonGroup );
			m_errorsCheckBox[id]->setText( SubtitleLine::errorText( (SubtitleLine::ErrorID)id ) );
			m_errorsCheckBox[id]->setChecked( true );
			checksCount++;
		}
	}

	m_marksCheckBox = new QCheckBox( errorsButtonGroup );
	m_marksCheckBox->setText( i18n( "User marks" ) );
	m_marksCheckBox->setChecked( true );
	checksCount++;

	QPushButton* selectAllButton = new QPushButton( errorsButtonGroup );
	selectAllButton->setText( i18n( "Select All" ) );
	QPushButton* selectNoneButton = new QPushButton( errorsButtonGroup );
	selectNoneButton->setText( i18n( "Select None" ) );

	connect( selectAllButton, SIGNAL( clicked() ), this, SLOT( selectAll() ) );
	connect( selectNoneButton, SIGNAL( clicked() ), this, SLOT( selectNone() ) );
	

	createLinesTargetButtons();
	createTextsTargetButtons();


	QGridLayout* errorsLayout = createLayout( errorsButtonGroup );
	int row = 0, col = 0;
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
	{
		if ( ! m_errorsCheckBox[id] ) continue;
		errorsLayout->addWidget( m_errorsCheckBox[id], row++, col );
		if ( row > (checksCount-1)/2 )
		{
			row = 0;
			col = 1;
		}
	}
	errorsLayout->addWidget( m_marksCheckBox, row++, col );
	QHBoxLayout* buttonsLayout = new QHBoxLayout();
	buttonsLayout->addStretch();
	buttonsLayout->addWidget( selectAllButton );
	buttonsLayout->addWidget( selectNoneButton );
	errorsLayout->addMultiCellLayout( buttonsLayout, checksCount / 2 + 1, checksCount / 2 + 1, 0, 1 );
}

int ClearErrorsDialog::errorFlagsToClear() const
{
	int errorFlags = 0;
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
		if ( m_errorsCheckBox[id] && m_errorsCheckBox[id]->isChecked() )
			errorFlags |= SubtitleLine::errorFlag( (SubtitleLine::ErrorID)id );

	switch ( selectedTextsTarget() )
	{
		case SubtitleLine::Primary:
		{
			return errorFlags;
		}
		case SubtitleLine::Secondary:
		{
			int secondaryErrorFlags = (errorFlags & SubtitleLine::PrimaryTextErrors) << 1;
			errorFlags = errorFlags & ~SubtitleLine::PrimaryTextErrors;
			return errorFlags | secondaryErrorFlags;
		}
		case SubtitleLine::Both:
		default:
		{
			int secondaryErrorFlags = (errorFlags & SubtitleLine::PrimaryTextErrors) << 1;
			return errorFlags | secondaryErrorFlags;
		}
	}
}

bool ClearErrorsDialog::clearMarks() const
{
	return m_marksCheckBox->isChecked();
}

void ClearErrorsDialog::selectAll()
{
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
		if ( m_errorsCheckBox[id] )
			m_errorsCheckBox[id]->setChecked( true );

	m_marksCheckBox->setChecked( true );
}

void ClearErrorsDialog::selectNone()
{
	for ( int id = 0; id < SubtitleLine::ErrorSIZE; ++id )
		if ( m_errorsCheckBox[id] )
			m_errorsCheckBox[id]->setChecked( false );

	m_marksCheckBox->setChecked( false );
}
