/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "durationlimitsdialog.h"
#include <timeedit.h>

#include <qlabel.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qlayout.h>

#include <klocale.h>

using namespace SubtitleComposer;

DurationLimitsDialog::DurationLimitsDialog( const Time& minDuration, const Time& maxDuration, QWidget* parent ):
	ActionWithTargetDialog( i18n( "Duration Limits" ), parent )
{
	m_maxButtonGroup = createButtonGroup( i18n( "Enforce maximun duration" ) );
	m_maxButtonGroup->setCheckable( true );

	QLabel* maxDurationLabel = new QLabel( i18n( "Maximun duration" ), m_maxButtonGroup );
	maxDurationLabel->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );

	m_maxDurationTimeEdit = new TimeEdit( m_maxButtonGroup );


	m_minButtonGroup = createButtonGroup( i18n( "Enforce minimun duration" ) );
	m_minButtonGroup->setCheckable( true );

	QLabel* minDurationLabel = new QLabel( i18n( "Minimun duration" ), m_minButtonGroup );
	minDurationLabel->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );

	m_preventOverlapCheckBox = new QCheckBox( m_minButtonGroup );
	m_preventOverlapCheckBox->setText( i18n( "Prevent overlapping" ) );
	m_preventOverlapCheckBox->setChecked( true );

	m_minDurationTimeEdit = new TimeEdit( m_minButtonGroup );


	createLinesTargetButtons();


	QGridLayout* maxLayout = createLayout( m_maxButtonGroup );
	maxLayout->addWidget( maxDurationLabel, 0, 0 );
	maxLayout->addWidget( m_maxDurationTimeEdit, 0, 1 );

	QGridLayout* minLayout = createLayout( m_minButtonGroup );
	minLayout->addWidget( minDurationLabel, 0, 0 );
	minLayout->addMultiCellWidget( m_preventOverlapCheckBox, 1, 1, 0, 1 );
	minLayout->addWidget( m_minDurationTimeEdit, 0, 1 );


	connect( m_maxButtonGroup, SIGNAL( toggled(bool) ), maxDurationLabel, SLOT( setEnabled(bool) ) );
	connect( m_maxButtonGroup, SIGNAL( toggled(bool) ), m_maxDurationTimeEdit, SLOT( setEnabled(bool) ) );

	connect( m_minButtonGroup, SIGNAL( toggled(bool) ), m_preventOverlapCheckBox, SLOT( setEnabled(bool) ) );
	connect( m_minButtonGroup, SIGNAL( toggled(bool) ), minDurationLabel, SLOT( setEnabled(bool) ) );
	connect( m_minButtonGroup, SIGNAL( toggled(bool) ), m_minDurationTimeEdit, SLOT( setEnabled(bool) ) );

	connect( m_maxDurationTimeEdit, SIGNAL( valueChanged(int) ), this, SLOT( onMaxDurationValueChanged(int) ) );
	connect( m_minDurationTimeEdit, SIGNAL( valueChanged(int) ), this, SLOT( onMinDurationValueChanged(int) ) );

	m_maxDurationTimeEdit->setValue( maxDuration.toMillis() );
	m_minDurationTimeEdit->setValue( minDuration.toMillis() );
}

void DurationLimitsDialog::onMaxDurationValueChanged( int value )
{
	if ( m_minDurationTimeEdit->value() > value )
		m_minDurationTimeEdit->setValue( value );
}

void DurationLimitsDialog::onMinDurationValueChanged( int value )
{
	if ( m_maxDurationTimeEdit->value() < value )
		m_maxDurationTimeEdit->setValue( value );
}

Time DurationLimitsDialog::minDuration() const
{
	return Time( m_minDurationTimeEdit->value() );
}

Time DurationLimitsDialog::maxDuration() const
{
	return Time( m_maxDurationTimeEdit->value() );
}

bool DurationLimitsDialog::enforceMaxDuration() const
{
	return m_maxButtonGroup->isChecked();
}

bool DurationLimitsDialog::enforceMinDuration() const
{
	return m_minButtonGroup->isChecked();
}

bool DurationLimitsDialog::preventOverlap() const
{
	return m_preventOverlapCheckBox->isChecked();
}
